@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -44,8 +44,11 @@ $ldap_base = "dc=example,dc=com";
 $ldap_login_attribute = "uid";
 $ldap_fullname_attribute = "cn";
 $ldap_filter = "(&(objectClass=person)($ldap_login_attribute={login}))";
+$ldap_scope = "sub"; # possible values: sub, one, base
 $ldap_use_exop_passwd = false;
 $ldap_use_ppolicy_control = false;
+$ldap_network_timeout = 10;
+$ldap_page_size = 0;
 
 # Active Directory mode
 # true: use unicodePwd as password field
@@ -95,7 +98,7 @@ $hash_options=[];
 $hash_options['crypt_salt_prefix'] = "$6$";
 $hash_options['crypt_salt_length'] = "6";
 
-# USE rate-limiting by IP and/or by user 
+# USE rate-limiting by IP and/or by user
 $use_ratelimit = false;
 # dir for json db's (system default tmpdir)
 #$ratelimit_dbdir = '/tmp';
@@ -144,6 +147,12 @@ $pwd_forbidden_ldap_fields = array();
 $pwd_complexity = 0;
 # use pwnedpasswords api v2 to securely check if the password has been on a leak
 $use_pwnedpasswords = false;
+# show password entropy bar (require php zxcvbn module)
+$pwd_display_entropy = false;
+# enforce password entropy check
+$pwd_check_entropy = false;
+# minimum entropy level required (when $pwd_check_entropy enabled)
+$pwd_min_entropy = 3;
 # Show policy constraints message:
 # always
 # never
@@ -239,6 +248,60 @@ $crypt_tokens = true;
 # Token lifetime in seconds
 $token_lifetime = "3600";
 
+## File cache parameters
+
+# cache type: File or Redis
+$cache_type = "File";
+
+# cache namespace: cache entries are grouped in this directory
+$cache_namespace = "sspCache";
+
+# cache directory: cache entries would be created in this extra
+# directory inside namespace
+$cache_directory = null;
+
+# default lifetime for all cached entry
+# not really usefull for now as each cache entry has a defined expiration
+# (see cache_token_expiration and cache_form_expiration)
+$cache_default_lifetime = 0;
+
+## Redis cache parameters
+
+# cache type: File or Redis
+#$cache_type = "Redis";
+
+# Data Source Name (DSN) for accessing to Redis server
+# See https://symfony.com/doc/current/components/cache/adapters/redis_adapter.html
+#$cache_redis_url = "redis:user:password@?host[redis1:6379]&timeout=5&dbindex=0";
+
+# cache namespace: cache entries are prefixed by this namespace
+#$cache_namespace = "sspCache";
+
+# default lifetime for all cached entries
+# not really usefull for now as each cache entry has a defined expiration
+# (see cache_token_expiration and cache_form_expiration)
+#$cache_default_lifetime = 0;
+
+## General cache parameters
+
+# $cache_token_expiration: integer, duration in seconds of cached objects
+# each time a token is involved
+# (for example when sending a token by sms or by mail)
+# it is recommended to set a value >= $token_lifetime
+$cache_token_expiration = 3600;
+# $cache_form_expiration: integer, duration in seconds of cached objects
+# at some steps when a user has to validate a form
+# (for example when validating the email address before we send the mail)
+# it is recommended to set a value high enough for a user to fill a form
+$cache_form_expiration = 120;
+
+# Reset URL (mandatory)
+$reset_url = "http://ssp.example.com/";
+# If inside a virtual host
+#$reset_url = ($_SERVER['HTTPS'] ? "https" : "http") . "://" . $_SERVER['SERVER_NAME'] . $_SERVER['SCRIPT_NAME'];
+# If behind a reverse proxy with a virtual host
+#$reset_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . "://" . $_SERVER['HTTP_X_FORWARDED_HOST'] . $_SERVER['SCRIPT_NAME'];
+
 ## Mail
 # LDAP mail attribute
 $mail_attributes = array( "mail", "gosaMailAlternateAddress", "proxyAddresses" );
@@ -275,9 +338,20 @@ $mail_priority = 3;
 ## SMS
 # Use sms
 $use_sms = true;
+# Get telephone number directly from LDAP (only first number entry)
+# and hide telephone number input field
+# default = false
+$sms_use_ldap = false;
 # SMS method (mail, api)
 $sms_method = "mail";
-$sms_api_lib = "lib/smsapi.inc.php";
+# path to SMS library to use
+# currently, 3 libraries are bundled:
+# - lib/smsapi-signal-cli.inc.php
+# - lib/smsapi-twilio.inc.php
+# - lib/smsovh/smsapi-ovh.inc.php
+# The last one needs php-ovh-sms dependency, do `composer update` in lib/smsovh
+# you can also write your own library
+$sms_api_lib = "";
 # GSM number attribute
 $sms_attributes = array( "mobile", "pager", "ipPhone", "homephone" );
 # Partially hide number
@@ -296,15 +370,18 @@ $sms_truncate_number_length = 10;
 # SMS token length
 $sms_token_length = 6;
 # Max attempts allowed for SMS token
-$max_attempts = 3;
+$sms_max_attempts_token = 3;
 
 # Encryption, decryption keyphrase, required if $use_tokens = true and $crypt_tokens = true, or $use_sms, or $crypt_answer
 # Please change it to anything long, random and complicated, you do not have to remember it
 # Changing it will also invalidate all previous tokens and SMS codes
 $keyphrase = "secret";
 
-# Reset URL (if behind a reverse proxy)
-#$reset_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . "://" . $_SERVER['HTTP_X_FORWARDED_HOST'] . $_SERVER['SCRIPT_NAME'];
+# Use attributes update page
+$use_attributes = false;
+#$attribute_mail = "mail";
+#$attribute_phone = "mobile";
+#$who_change_attributes = "manager";
 
 # Display help messages
 $show_help = true;
@@ -340,13 +417,29 @@ $login_forbidden_chars = "*()&|";
 
 ## Captcha
 $use_captcha = false;
+$captcha_class = "InternalCaptcha";
+
+#$captcha_class = "FriendlyCaptcha";
+#$friendlycaptcha_apiurl  = "https://api.friendlycaptcha.com/api/v1/siteverify";
+#$friendlycaptcha_sitekey = "secret";
+#$friendlycaptcha_secret  = "secret";
+
+#$captcha_class       = "ReCaptcha";
+#$recaptcha_url       = "https://www.google.com/recaptcha/api/siteverify";
+#$recaptcha_sitekey   = "sitekey";
+#$recaptcha_secretkey = "secretkey";
+#$recaptcha_minscore  = 0.5;
 
 ## Default action
 # change
 # sendtoken
 # sendsms
+# changecustompwdfield
 $default_action = "change";
 
+## default page of custom password field to display
+#$default_custompwdindex = 0;
+
 ## Rest API
 $use_restapi = false;
 
@@ -355,6 +448,9 @@ $use_restapi = false;
 #$messages['passwordchangedextramessage'] = NULL;
 #$messages['changehelpextramessage'] = NULL;
 
+# Audit
+#$audit_log_file = "/var/log/self-service-password/audit.log";
+
 ## Pre Hook
 # Launch a prehook script before changing password.
 # Script should return with 0, to allow password change.
@@ -381,10 +477,8 @@ $use_restapi = false;
 #setlocale(LC_CTYPE, "en_US.UTF-8");
 
 # Hide some messages to not disclose sensitive information
-# These messages will be replaced by badcredentials error
-# by default mailnomatch is obscured since it can disclose account existence
-$obscure_failure_messages = array("mailnomatch");
 $obscure_usernotfound_sendtoken = true;
+$obscure_notfound_sendsms = true;
 
 # HTTP Header name that may hold a login to preset in forms
 #$header_name_preset_login="Auth-User";
@@ -397,8 +491,13 @@ $obscure_usernotfound_sendtoken = true;
 #$smarty_cache_dir = "/var/cache/self-service-password/cache";
 
 # Smarty debug mode - will popup debug information on web interface
+# and add many smarty debug messages in error logs
 $smarty_debug = false;
 
+## Custom Password Fields
+# Change Custom Password Fields
+$change_custompwdfield = array();
+
 # Allow to override current settings with local configuration
 if (file_exists (__DIR__ . '/config.inc.local.php')) {
     require_once __DIR__ . '/config.inc.local.php';
