@@ -3,7 +3,7 @@
 #==============================================================================
 # Version
 #==============================================================================
-$version = "1.5.3";
+$version = "1.7.1";
 
 #==============================================================================
 # Configuration
@@ -13,16 +13,8 @@ require_once("../conf/config.inc.php");
 #==============================================================================
 # Includes
 #==============================================================================
-require_once("../lib/vendor/defuse-crypto.phar");
-require_once("../lib/vendor/autoload.php");
+require_once("../vendor/autoload.php");
 require_once("../lib/functions.inc.php");
-if ($use_captcha) {
-    require_once("../lib/captcha.inc.php");
-}
-// should be included by ../lib/vendor/autoload.php
-//if ($use_pwnedpasswords) {
-//    require_once("../lib/vendor/mxrxdxn/pwned-passwords/src/PwnedPasswords/PwnedPasswords.php");
-//}
 
 #==============================================================================
 # VARIABLES
@@ -34,12 +26,11 @@ else { $source="unknown"; }
 #==============================================================================
 # Language
 #==============================================================================
-require_once("../lib/detectbrowserlanguage.php");
 # Available languages
 $files = glob("../lang/*.php");
 $languages = str_replace(".inc.php", "", $files);
 $languages = str_replace("../lang/", "", $languages);
-$lang = detectLanguage($lang, $languages);
+$lang = \Ltb\Language::detect_language($lang, $allowed_lang ? array_intersect($languages,$allowed_lang) : $languages);
 require_once("../lang/$lang.inc.php");
 
 # Remove default questions
@@ -80,35 +71,83 @@ if ( ! function_exists('mb_internal_encoding') ) { $dependency_check_results[] =
 # Check PHP xml presence
 if ( ! function_exists('utf8_decode') ) { $dependency_check_results[] = "nophpxml"; }
 
+# Check crypt_tokens option
+if ( $use_sms and !$crypt_tokens ) { $dependency_check_results[] = "nocrypttokens"; }
+
 # Check keyphrase setting
 if ( ( ( $use_tokens and $crypt_tokens ) or $use_sms or $crypt_answers ) and ( empty($keyphrase) or $keyphrase == "secret") ) { $dependency_check_results[] = "nokeyphrase"; }
 
+# Check reset_url setting
+if ( $use_tokens and empty($reset_url) ) { $dependency_check_results[] = "noreseturl"; }
 
 #==============================================================================
 # Email Config
 #==============================================================================
-use PHPMailer\PHPMailer\PHPMailer;
-use PHPMailer\PHPMailer\Exception;
-use PHPMailer\PHPMailer\SMTP;
-$mailer = new PHPMailer;
-$mailer->Priority      = $mail_priority;
-$mailer->CharSet       = $mail_charset;
-$mailer->ContentType   = $mail_contenttype;
-$mailer->WordWrap      = $mail_wordwrap;
-$mailer->Sendmail      = $mail_sendmailpath;
-$mailer->Mailer        = $mail_protocol;
-$mailer->SMTPDebug     = $mail_smtp_debug;
-$mailer->Debugoutput   = $mail_debug_format;
-$mailer->Host          = $mail_smtp_host;
-$mailer->Port          = $mail_smtp_port;
-$mailer->SMTPSecure    = $mail_smtp_secure;
-$mailer->SMTPAutoTLS   = $mail_smtp_autotls;
-$mailer->SMTPAuth      = $mail_smtp_auth;
-$mailer->Username      = $mail_smtp_user;
-$mailer->Password      = $mail_smtp_pass;
-$mailer->SMTPKeepAlive = $mail_smtp_keepalive;
-$mailer->SMTPOptions   = $mail_smtp_options;
-$mailer->Timeout       = $mail_smtp_timeout;
+$mailer = new \Ltb\Mail(
+                           $mail_priority,
+                           $mail_charset,
+                           $mail_contenttype,
+                           $mail_wordwrap,
+                           $mail_sendmailpath,
+                           $mail_protocol,
+                           $mail_smtp_debug,
+                           $mail_debug_format,
+                           $mail_smtp_host,
+                           $mail_smtp_port,
+                           $mail_smtp_secure,
+                           $mail_smtp_autotls,
+                           $mail_smtp_auth,
+                           $mail_smtp_user,
+                           $mail_smtp_pass,
+                           $mail_smtp_keepalive,
+                           $mail_smtp_options,
+                           $mail_smtp_timeout
+                       );
+
+#==============================================================================
+# LDAP Config
+#==============================================================================
+$ldapInstance = new \Ltb\Ldap(
+                                 $ldap_url,
+                                 $ldap_starttls,
+                                 isset($ldap_binddn) ? $ldap_binddn : null,
+                                 isset($ldap_bindpw) ? $ldap_bindpw : null,
+                                 isset($ldap_network_timeout) ? $ldap_network_timeout : null,
+                                 $ldap_base,
+                                 null,
+                                 isset($ldap_krb5ccname) ? $ldap_krb5ccname : null,
+                                 isset($ldap_page_size) ? $ldap_page_size : 0
+                             );
+
+#==============================================================================
+# Cache Config
+#==============================================================================
+$cache_class = '\\Ltb\\Cache\\'.$cache_type.'Cache';
+switch($cache_type)
+{
+    case "File":
+        $sspCache = new $cache_class( $cache_namespace,
+                                      $cache_default_lifetime,
+                                      $cache_directory
+                                    );
+        break;
+
+    case "Redis":
+        $sspCache = new $cache_class( $cache_redis_url,
+                                      $cache_namespace,
+                                      $cache_default_lifetime
+                                    );
+        break;
+
+    default:
+        error_log("Error: unknown cache type: $cache_type");
+        exit(1);
+}
+
+#==============================================================================
+# Captcha Config
+#==============================================================================
+require_once(__DIR__ . "/../lib/captcha.inc.php");
 
 #==============================================================================
 # Other default values
@@ -138,7 +177,10 @@ $pwd_policy_config = array(
     "use_pwnedpasswords"        => $use_pwnedpasswords,
     "pwd_no_special_at_ends"    => $pwd_no_special_at_ends,
     "pwd_forbidden_words"       => $pwd_forbidden_words,
-    "pwd_forbidden_ldap_fields" => $pwd_forbidden_ldap_fields
+    "pwd_forbidden_ldap_fields" => $pwd_forbidden_ldap_fields,
+    "pwd_display_entropy"       => $pwd_display_entropy,
+    "pwd_check_entropy"         => $pwd_check_entropy,
+    "pwd_min_entropy"           => $pwd_min_entropy
 );
 
 if (!isset($pwd_show_policy_pos)) { $pwd_show_policy_pos = "above"; }
@@ -152,6 +194,9 @@ $rrl_config = array(
     "filter_by_ip" => isset($ratelimit_filter_by_ip_jsonfile) ? $ratelimit_filter_by_ip_jsonfile : ""
 );
 
+# Preset login with login_hint
+if (isset($_REQUEST["login_hint"]) and $_REQUEST["login_hint"]) { $presetLogin = strval($_REQUEST["login_hint"]); }
+
 #==============================================================================
 # Route to action
 #==============================================================================
@@ -167,12 +212,43 @@ if ( $change_sshkey ) { array_push( $available_actions, "changesshkey"); }
 if ( $use_questions ) { array_push( $available_actions, "resetbyquestions", "setquestions"); }
 if ( $use_tokens ) { array_push( $available_actions, "resetbytoken", "sendtoken"); }
 if ( $use_sms ) { array_push( $available_actions, "resetbytoken", "sendsms"); }
+if ( !empty($change_custompwdfield) ) { array_push( $available_actions, "changecustompwdfield"); }
+if ( $use_attributes ) { array_push( $available_actions, "setattributes" ); }
+array_push( $available_actions, "checkentropy" );
 
 # Ensure requested action is available, or fall back to default
 if ( ! in_array($action, $available_actions) ) { $action = $default_action; }
 
+error_reporting(0);
+if ($debug) {
+    error_reporting(E_ALL);
+    # Set debug for LDAP
+    ldap_set_option(NULL, LDAP_OPT_DEBUG_LEVEL, 7);
+}
+
 if (file_exists($action.".php")) { require_once($action.".php"); }
 
+#==============================================================================
+# Audit
+#==============================================================================
+if ($audit_log_file and !preg_match("/empty.*form/", $result)) {
+    require_once("../lib/audit.inc.php");
+    auditlog($audit_log_file, $userdn, $login, $action, $result);
+}
+
+#==============================================================================
+# Generate captcha
+#==============================================================================
+$captcha_html = '';
+$captcha_js   = '';
+$captcha_css  = '';
+if(isset($use_captcha) && $use_captcha == true)
+{
+    $captcha_html = $captchaInstance->generate_html_captcha($messages);
+    $captcha_js = $captchaInstance->generate_js_captcha();
+    $captcha_css = $captchaInstance->generate_css_captcha();
+}
+
 #==============================================================================
 # Smarty
 #==============================================================================
@@ -187,12 +263,14 @@ $smarty->setTemplateDir('../templates/');
 $smarty->setCompileDir($compile_dir);
 $smarty->setCacheDir($cache_dir);
 $smarty->debugging = $smarty_debug;
-
-error_reporting(0);
-if ($debug) {
-    error_reporting(E_ALL);
-    # Set debug for LDAP
-    ldap_set_option(NULL, LDAP_OPT_DEBUG_LEVEL, 7);
+if(isset($smarty_debug) && $smarty_debug == true )
+{
+    $smarty->error_reporting = E_ALL;
+}
+else
+{
+    # Do not report smarty stuff unless $smarty_debug == true
+    $smarty->error_reporting = E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING;
 }
 
 # Assign configuration variables
@@ -208,41 +286,42 @@ $smarty->assign('use_questions', $use_questions);
 $smarty->assign('use_tokens', $use_tokens);
 $smarty->assign('use_sms', $use_sms);
 $smarty->assign('change_sshkey', $change_sshkey);
+if(empty($change_custompwdfield)) {
+    $smarty->assign('change_custompwdfield', false);
+} else {
+    $change_custompwdfield_labels = array();
+    for ($i = 0; $i < count($change_custompwdfield); $i++) {
+        $change_custompwdfield_labels[$i] = array();
+        if (!isset($change_custompwdfield[$i]['label'])) {
+            $change_custompwdfield[$i]['label'] = "Custom Password ".$i;
+        } # default generic label
+        if (!isset($change_custompwdfield[$i]['msg_changehelpextramessage'])) {
+            $change_custompwdfield[$i]['msg_changehelpextramessage'] = "";
+        } # default empty help message
+        $change_custompwdfield_labels[$i]['label'] = $change_custompwdfield[$i]['label'];
+        $change_custompwdfield_labels[$i]['msg_changehelpextramessage'] = $change_custompwdfield[$i]['msg_changehelpextramessage'];
+    }
+    $smarty->assign('change_custompwdfield', $change_custompwdfield_labels);
+}
 $smarty->assign('mail_address_use_ldap', $mail_address_use_ldap);
+$smarty->assign('sms_use_ldap', $sms_use_ldap);
 $smarty->assign('default_action', $default_action);
+$smarty->assign('captcha_html', $captcha_html);
+$smarty->assign('captcha_js', $captcha_js);
+$smarty->assign('captcha_css', $captcha_css);
 //$smarty->assign('',);
 
 if (isset($source)) { $smarty->assign('source', $source); }
 if (isset($login)) { $smarty->assign('login', $login); }
 if (isset($token)) { $smarty->assign('token', $token); }
 if (isset($use_captcha)) { $smarty->assign('use_captcha', $use_captcha); }
-// TODO : Make it clean function show_policy - START
-if (isset($pwd_show_policy_pos)) {
-    $smarty->assign('pwd_show_policy_pos', $pwd_show_policy_pos);
-    $smarty->assign('pwd_show_policy', $pwd_show_policy);
-    $smarty->assign('pwd_show_policy_onerror', true);
-    if ( $pwd_show_policy === "onerror" ) {
-        if ( !preg_match( "/tooshort|toobig|minlower|minupper|mindigit|minspecial|forbiddenchars|sameasold|notcomplex|sameaslogin|pwned|specialatends/" , $result) ) {
-            $smarty->assign('pwd_show_policy_onerror', false);
-        } else {
-            $smarty->assign('pwd_show_policy_onerror', true);
-        }
-    }
-    if (isset($pwd_min_length)) { $smarty->assign('pwd_min_length', $pwd_min_length); }
-    if (isset($pwd_max_length)) { $smarty->assign('pwd_max_length', $pwd_max_length); }
-    if (isset($pwd_min_lower)) { $smarty->assign('pwd_min_lower', $pwd_min_lower); }
-    if (isset($pwd_min_upper)) { $smarty->assign('pwd_min_upper', $pwd_min_upper); }
-    if (isset($pwd_min_digit)) { $smarty->assign('pwd_min_digit', $pwd_min_digit); }
-    if (isset($pwd_min_special)) { $smarty->assign('pwd_min_special', $pwd_min_special); }
-    if (isset($pwd_complexity)) { $smarty->assign('pwd_complexity', $pwd_complexity); }
-    if (isset($pwd_diff_last_min_chars)) { $smarty->assign('pwd_diff_last_min_chars', $pwd_diff_last_min_chars); }
-    if (isset($pwd_forbidden_chars)) { $smarty->assign('pwd_forbidden_chars', $pwd_forbidden_chars); }
-    if (isset($pwd_no_reuse)) { $smarty->assign('pwd_no_reuse', $pwd_no_reuse); }
-    if (isset($pwd_diff_login)) { $smarty->assign('pwd_diff_login', $pwd_diff_login); }
-    if (isset($use_pwnedpasswords)) { $smarty->assign('use_pwnedpasswords', $use_pwnedpasswords); }
-    if (isset($pwd_no_special_at_ends)) { $smarty->assign('pwd_no_special_at_ends', $pwd_no_special_at_ends); }
+
+\Ltb\Ppolicy::smarty_assign_ppolicy($smarty, $pwd_show_policy_pos, $pwd_show_policy, $result, $pwd_policy_config);
+
+if (isset($custompwdindex)) {
+    $smarty->assign('custompwdindex', $custompwdindex);
+    if (isset($change_custompwdfield[$custompwdindex]['msg_passwordchangedextramessage'])) { $smarty->assign('msg_passwordchangedextramessage', $change_custompwdfield[$custompwdindex]['msg_passwordchangedextramessage']); }
 }
-// TODO : Make it clean function show_policy - END
 if (isset($smsdisplay)) { $smarty->assign('smsdisplay', $smsdisplay); }
 // TODO : Make it clean $prehook_return/$posthook_return - START
 if (isset($prehook_return)) {
@@ -264,6 +343,9 @@ if (isset($show_extended_error)) { $smarty->assign('show_extended_error', $show_
 if (isset($extended_error_msg)) { $smarty->assign('extended_error_msg', $extended_error_msg); }
 //if (isset($var)) { $smarty->assign('var', $var); }
 
+if (isset($use_attributes) && $use_attributes && isset($attribute_mail)) { $smarty->assign('attribute_mail_update', true); }
+if (isset($use_attributes) && $use_attributes && isset($attribute_phone)) { $smarty->assign('attribute_phone_update', true); }
+
 # Assign messages
 $smarty->assign('lang',$lang);
 foreach ($messages as $key => $message) {
@@ -278,11 +360,11 @@ if (isset($questions_count)) { $smarty->assign('questions_count', $questions_cou
 if (isset($question)) { $smarty->assign('question', $question); }
 
 if (isset($login)) { $smarty->assign('login', $login); }
+if (isset($formtoken)) { $smarty->assign('formtoken', $formtoken); }
 if (isset($usermail)) { $smarty->assign('usermail', $usermail); }
 if (isset($displayname[0])) { $smarty->assign('displayname', $displayname[0]); }
 if (isset($encrypted_sms_login)) { $smarty->assign('encrypted_sms_login', $encrypted_sms_login); }
-
-if (isset($obscure_failure_messages) && in_array($result, $obscure_failure_messages) ) { $result = "badcredentials"; }
+if (isset($formtoken)) { $smarty->assign('formtoken', $formtoken); }
 
 # Set error message, criticity and fa_class
 
@@ -290,7 +372,7 @@ if ($result) {
     $smarty->assign('error', $messages[$result]);
     // TODO : Make it clean $error_sms - START
     if ($action == 'sendsms') {
-        if (isset($result) && ($result == 'smscrypttokensrequired' || $result == 'smsuserfound' || $result == 'smssent' || $result == 'tokenattempts')) {
+        if (isset($result) && ($result == 'smscrypttokensrequired' || $result == 'smsuserfound' || $result == 'smssent' || $result == 'smssent_ifexists' || $result == 'tokenattempts')) {
             $smarty->assign('error_sms', $result);
         } else {
             $smarty->assign('error_sms', false);
