@@ -1,10 +1,9 @@
-<html><head>
-<meta http-equiv="content-type" content="text/html; charset=UTF-8"></head><body><pre>&lt;?php
+<?php
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,6 +29,8 @@ $messages['phpupgraderequired'] = "Es requereix una actualització de PHP";
 $messages['nophpldap'] = "Cal instal·lar PHP LDAP per fer servir aquesta eina";
 $messages['nophpmhash'] = "Cal instal·lar PHP mhash per fer servir el mode Samba";
 $messages['nokeyphrase'] = "El xifrat per testimoni requereix una cadena aleatòria a la configuració de la frase clau";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "No es pot accedir al servidor LDAP";
 $messages['loginrequired'] = "Cal el nom d'usuari";
 $messages['oldpasswordrequired'] = "Cal la contrasenya anterior";
@@ -37,6 +38,7 @@ $messages['newpasswordrequired'] = "Cal la contrasenya actual";
 $messages['confirmpasswordrequired'] = "Si us plau, confirmeu la contrasenya nova";
 $messages['passwordchanged'] = "La seva contrasenya ha canviat";
 $messages['nomatch'] = "Les contrasenyes no són iguals";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "El nom d'usuari o la contrasenya són incorrectes";
 $messages['passworderror'] = "El servidor ha refusat la contrasenya";
 $messages['title'] = "Autoservei de canvi de contrasenyes";
@@ -103,8 +105,9 @@ $messages['notcomplex'] = "La vostra contrasenya no té prou tipus diferents de
 $messages['policycomplex'] = "Mínim de classes de caràcters diferents:";
 $messages['sms'] = "SMS Numero";
 $messages['smsresetmessage'] = "El testimoni de restabliment de contrasenya és:";
-$messages['sendsmshelp'] = "Introdueixi el seu nom d'usuari per obtenir un testimoni de restabliment de contrasenya. A continuació, escriviu el testimoni en l'SMS enviat.";
+$messages['sendsmshelpnosms'] = "Introdueixi el seu nom d'usuari per obtenir un testimoni de restabliment de contrasenya. A continuació, escriviu el testimoni en l'SMS enviat.";
 $messages['smssent'] = "Un codi de confirmació ha estat enviat per SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Error enviant el SMS";
 $messages['smsnonumber'] = "No es pot trobar el número de telèfon mòbil";
 $messages['userfullname'] = "Nom d'usuari complert";
@@ -150,6 +153,7 @@ $messages['forbiddenwords'] = "La vostra contrasenya contenen paraules o cadenes
 $messages['policyforbiddenwords'] = "La vostra contrasenya no pot contenir:";
 $messages['forbiddenldapfields'] = "La vostra contrasenya conté valors de camps d'LDAP";
 $messages['policyforbiddenldapfields'] = "La vostra contrasenya no pot contenir valors dels següents camps d'LDAP:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "Nom de pila";
 $messages['ldap_givenName'] = "Nom complet";
 $messages['ldap_sn'] = "Cognom";
@@ -158,4 +162,24 @@ $messages["questionspopulatehint"] = "Introduïu només el vostre usuari per obt
 $messages['badquality'] = "La qualitat de la contrasenya és molt baixa";
 $messages['tooyoung'] = "La contrasenya s'ha canviat massa recentment";
 $messages['inhistory'] = "La contresenya es troba dins l'històric de les contrasenyes antigues";
-</pre></body></html>
\ No newline at end of file
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['invalidsshkey'] = "Input SSH Key looks invalid";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
