@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP Upgrade erforderlich";
 $messages['nophpldap'] = "Sie benötigen die PHP LDAP Erweiterung um dieses Tool zu nutzen";
 $messages['nophpmhash'] = "Sie benötigen die PHP mhash Erweiterung um den Samba Modus zu nutzen";
 $messages['nokeyphrase'] = "Die Token Verschlüsselung erfordert eine zufällige Zeichenfolge in der Konfigurationsvariable 'keyphrase'";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Kein Zugriff auf den LDAP-Server möglich";
 $messages['loginrequired'] = "Ihr Benutzername wird benötigt";
 $messages['oldpasswordrequired'] = "Ihr altes Passwort wird benötigt";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Ihr neues Passwort wird benötigt";
 $messages['confirmpasswordrequired'] = "Bitte bestätigen Sie Ihr neues Passwort";
 $messages['passwordchanged'] = "Ihr Passwort wurde erfolgreich geändert";
 $messages['nomatch'] = "Die angegebenen Passwörter stimmen nicht überein";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Benutzername oder Passwort sind inkorrekt";
 $messages['passworderror'] = "Das Passwort wurde vom LDAP-Verzeichnis nicht akzeptiert";
 $messages['title'] = "Passwortverwaltung";
@@ -84,7 +87,7 @@ $messages['mail'] = "E-Mail";
 $messages['mailrequired'] = "Ihre E-Mail-Adresse wird benötigt";
 $messages['mailnomatch'] = "Die angegebene E-Mail-Adresse ist nicht für den Benutzernamen hinterlegt";
 $messages['tokensent'] = "Eine Bestätigungsmail wurde versandt";
-$messages['tokensent_ifexists'] = "If the account exists, a confirmation email has been sent to the associated email address";
+$messages['tokensent_ifexists'] = "Wenn das Konto existiert, wurde eine Bestätigungs-E-Mail an die zugehörige E-Mail-Adresse gesendet";
 $messages['tokennotsent'] = "Fehler beim Versenden der Bestätigungsmail";
 $messages['tokenrequired'] = "Token benötigt";
 $messages['tokennotvalid'] = "Token ungültig";
@@ -99,8 +102,9 @@ $messages['notcomplex'] = "Ihr Passwort hat nicht genug unterschiedliche Zeichen
 $messages['policycomplex'] = "Minimum verschiedener Zeichenklassen:";
 $messages['sms'] = "Mobilfunknummer";
 $messages['smsresetmessage'] = "Ihr Bestätigungscode für die Passwortrücksetzung lautet:";
-$messages['sendsmshelp'] = "Geben Sie Ihren Benutzernamen ein, um einen Bestätigungscode für die Passwortrücksetzung zu erhalten. Geben Sie nachfolgend den per SMS erhaltenen Bestätigungscode ein.";
+$messages['sendsmshelpnosms'] = "Geben Sie Ihren Benutzernamen ein, um einen Bestätigungscode für die Passwortrücksetzung zu erhalten. Geben Sie nachfolgend den per SMS erhaltenen Bestätigungscode ein.";
 $messages['smssent'] = "Ein Bestätigungscode wurde per SMS versandt";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Fehler beim Versenden der SMS";
 $messages['smsnonumber'] = "Kann Mobilfunknummer nicht finden";
 $messages['userfullname'] = "Vollständiger Name des Benutzers";
@@ -115,6 +119,7 @@ $messages['nophpmbstring'] = "Sie müssen PHP mbstring installieren";
 $messages['menuquestions'] = "Frage";
 $messages['menutoken'] = "Rücksetzen per E–Mail";
 $messages['menusms'] = "Rücksetzen per SMS";
+$messages['menucustompwdfield'] = "Rücksetzen des Passworts für ";
 $messages['nophpxml'] = "Sie benötigen die PHP XML Erweiterung um dieses Tool zu nutzen";
 $messages['tokenattempts'] = "Ungültiges Token, versuchen Sie es erneut";
 $messages['emptychangeform'] = "Passwort ändern";
@@ -135,6 +140,11 @@ $messages['emptysshkeychangeform'] = "Ändern Sie Ihren SSH-Schlüssel";
 $messages['changesshkeymessage'] = "Hallo Benutzer {login}, \n\nder SSH-Schlüssel wurde geändert.\n\nWenn Sie diese Änderung nicht eingeleitet haben, wenden Sie sich bitte umgehend an Ihren Administrator.";
 $messages['menusshkey'] = "SSH-Schlüssel";
 $messages['changesshkeysubject'] = "Ihr SSH-Schlüssel wurde geändert";
+
+$messages['changecustompwdfieldhelp'] = "Um das Passwort zu ändern, müssen Sie zuerst ihr Accountpasswort angeben";
+$messages['changehelpcustompwdfield'] = "Ändern sie Ihr Passwort für ";
+$messages['newcustompassword'] = "neues Passwort für ";
+$messages['confirmcustompassword'] = "neues Passwort bestätigen";
 $messages['pwned'] = "Ihr neues Passwort gilt gemäß Sicherheitsdatenbanken als bekannt und entschlüsselbar, Sie sollten ein anderes Passwort wählen.";
 $messages['policypwned'] = "Ihr neues Passwort sollte in Sicherheitsdatenbanken unbekannt und damit sicher gewählt sein.";
 $messages['throttle'] = "Ihr Zugriff wurde aufgrund zu häufiger Anfragen abgelehnt, versuchen Sie es später erneut.";
@@ -147,6 +157,7 @@ $messages['forbiddenwords'] = "Ihr Passwort enthält verbotene Worte oder Zeiche
 $messages['policyforbiddenwords'] = "Ihr Passwort darf nicht enthalten:";
 $messages['forbiddenldapfields'] = "Ihr Passwort enthält Werte aus Ihrem LDAP-Eintrag";
 $messages['policyforbiddenldapfields'] = "Ihr Passwort darf keine Werte aus folgenden LDAP-Feldern enthalten:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "Name";
 $messages['ldap_givenName'] = "Vorname";
 $messages['ldap_sn'] = "Nachname";
@@ -155,3 +166,18 @@ $messages["questionspopulatehint"] = "Geben Sie Ihren Benutzernamen ein, um die
 $messages['badquality'] = "Geringe Passwortqualität";
 $messages['tooyoung'] = "Das Passwort wurde zu häufig geändert";
 $messages['inhistory'] = "Das Passwort wurde früher bereits verwendet";
+$messages['unknowncustompwdfield'] = "Das im Link angegebene Passwort kann nicht gefunden werden";
+$messages['sameascustompwd'] = "Das neue Passwort ist das gleiche wie ein anderes!";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
