@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -28,6 +28,8 @@ $messages['phpupgraderequired'] = "PHP vajab uuendamist";
 $messages['nophpldap'] = "Sul on vaja paigaldada PHP LDAP, et kasutada seda tööriista";
 $messages['nophpmhash'] = "Sul on vaja paigaldada PHP mhash, et kasutada Samba režiimi";
 $messages['nokeyphrase'] = "Tokeni krüpteerimine nõuab juhuslikku märgijada võtmejada seadistuses";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Ei ole võimalik saada ühendust LDAP kataloogiga";
 $messages['loginrequired'] = "Sinu kasutajanimi on kohustuslik";
 $messages['oldpasswordrequired'] = "Sinu vana parool on kohustuslik";
@@ -36,6 +38,7 @@ $messages['confirmpasswordrequired'] = "Palun kinnita uus parool";
 $messages['passwordchanged'] = "Sinu parool on muudetud";
 $messages['sshkeychanged'] = "Sinu SSH võti on muudetud";
 $messages['nomatch'] = "Paroolid ei kattu";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Kasutajanimi või parool on vale";
 $messages['passworderror'] = "Parooli muudatus lükati tagasi LDAP kataloogi poolt";
 $messages['sshkeyerror'] = "SSH võtme muudatus lükati tagasi LDAP kataloogi poolt";
@@ -110,8 +113,9 @@ $messages['notcomplex'] = "Sinu parool ei sisaldada piisavalt erinevaid tähemä
 $messages['policycomplex'] = "Miinimum arv erinevaid tähemärgi klasse:";
 $messages['sms'] = "SMS number";
 $messages['smsresetmessage'] = "Sinu parooli lähtestamise ajutine kood on:";
-$messages['sendsmshelp'] = "Sisesta oma kasutajanimi, et saada parooli lähtestamise ajutine kood. Kasuta SMS teel saadud ajutist koodi.";
+$messages['sendsmshelpnosms'] = "Sisesta oma kasutajanimi, et saada parooli lähtestamise ajutine kood. Kasuta SMS teel saadud ajutist koodi.";
 $messages['smssent'] = "Kinnituskood saadetud SMS'iga";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Viga SMS saatmisel";
 $messages['smsnonumber'] = "Ei leia mobiiltelefoni numbrit";
 $messages['userfullname'] = "Ees- ja perenimi";
@@ -147,6 +151,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -155,3 +160,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
