@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP upgrade required";
 $messages['nophpldap'] = "Απαιτείται η εγκατάσταση του πρόσθετου PHP LDAP για τη λειτουργία αυτής της εφαρμογής";
 $messages['nophpmhash'] = "Απαιτείται η εγκατάσταση του πρόσθετου PHP mhash για τη χρήση Samba";
 $messages['nokeyphrase'] = "Token encryption requires a random string in keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Αδυναμία πρόσβασης στην υπηρεσία καταλόγου";
 $messages['loginrequired'] = "Απαιτείται η καταχώρηση του ονόματος χρήστη";
 $messages['oldpasswordrequired'] = "Απαιτείται η καταχώρηση του ισχύοντος κωδικού σας";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Απαιτείται η καταχώρηση
 $messages['confirmpasswordrequired'] = "Απαιτείται η επιβεβαίωση του νέου σας κωδικού";
 $messages['passwordchanged'] = "Ο κωδικός σας άλλαξε";
 $messages['nomatch'] = "Δεν καταχωρήσατε δύο φορές τον ίδιο νέο κωδικό";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Το όνομα χρήστη ή ο κωδικός είναι λάθος";
 $messages['passworderror'] = "Ο κωδικός δεν έγινε δεκτός από την υπηρεσία καταλόγου";
 $messages['title'] = "Αλλαγή/Ανάκτηση Κωδικού";
@@ -100,8 +103,9 @@ $messages['notcomplex'] = "Ο κωδικός σας δεν περιέχει αρ
 $messages['policycomplex'] = "Ελάχιστος αριθμός διαφορετικών ειδών χαρακτήρων:";
 $messages['sms'] = "Αριθμός SMS";
 $messages['smsresetmessage'] = "Το μοναδικό αναγνωριστικό αλλαγής του κωδικού σας είναι:";
-$messages['sendsmshelp'] = "Καταχωρήστε το όνομα χρήστη για να λάβετε μοναδικό αναγνωριστικό αλλαγής κωδικού. Στη συνέχεια καταχωρήστε το μοναδικό αναγνωριστικό που λάβατε μέσω SMS.";
+$messages['sendsmshelpnosms'] = "Καταχωρήστε το όνομα χρήστη για να λάβετε μοναδικό αναγνωριστικό αλλαγής κωδικού. Στη συνέχεια καταχωρήστε το μοναδικό αναγνωριστικό που λάβατε μέσω SMS.";
 $messages['smssent'] = "Ένας κωδικός επιβεβαίωσης στάλθηκε μέσω SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Λάθος στην αποστολή SMS";
 $messages['smsnonumber'] = "Δεν υπάρχει αριθμός κινητού τηλεφώνου";
 $messages['userfullname'] = "Ονοματεπώνυμο χρήστη";
@@ -145,6 +149,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -153,3 +158,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
