@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP upgrade required";
 $messages['nophpldap'] = "You should install PHP LDAP to use this tool";
 $messages['nophpmhash'] = "You should install PHP mhash to use Samba mode";
 $messages['nokeyphrase'] = "Token encryption requires a random string in keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Cannot access LDAP directory";
 $messages['loginrequired'] = "Your login is required";
 $messages['oldpasswordrequired'] = "Your old password is required";
@@ -34,14 +36,15 @@ $messages['confirmpasswordrequired'] = "Please confirm your new password";
 $messages['passwordchanged'] = "Your password was changed";
 $messages['sshkeychanged'] = "Your SSH Key was changed";
 $messages['nomatch'] = "Passwords mismatch";
-$messages['badcredentials'] = "Login or password incorrect";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
+$messages['badcredentials'] = "Login and/or password incorrect";
 $messages['passworderror'] = "Password was refused by the LDAP directory";
 $messages['sshkeyerror'] = "SSH Key was refused by the LDAP directory";
 $messages['title'] = "Self service password";
 $messages['login'] = "Login";
 $messages['oldpassword'] = "Old password";
 $messages['newpassword'] = "New password";
-$messages['confirmpassword'] = "Confirm";
+$messages['confirmpassword'] = "Confirm password";
 $messages['submit'] = "Send";
 $messages['getuser'] = "Get user";
 $messages['tooshort'] = "Your password is too short";
@@ -85,11 +88,11 @@ $messages['changehelpsshkey'] = "<a href=\"?action=changesshkey\">Change your SS
 $messages['changesshkeyhelp'] = "Enter your password and new SSH key.";
 $messages['resetmessage'] = "Hello {login},\n\nClick here to reset your password:\n{url}\n\nIf you didn't request a password reset, please ignore this email.";
 $messages['resetsubject'] = "Reset your password";
-$messages['sendtokenhelp'] = "Enter your user name and your email address to reset your password. When you receive the email, click the link inside to complete the password reset.";
-$messages['sendtokenhelpnomail'] = "Enter your user name to reset your password. An email will be sent to the address associated with the supplied user name. When you receive this email, click the link inside to complete the password reset.";
+$messages['sendtokenhelp'] = "Enter your login and your email address to reset your password. When you receive the email, click the link inside to complete the password reset.";
+$messages['sendtokenhelpnomail'] = "Enter your login to reset your password. An email will be sent to the address associated with the supplied user name. When you receive this email, click the link inside to complete the password reset.";
 $messages['mail'] = "Mail";
 $messages['mailrequired'] = "Your email address is required";
-$messages['mailnomatch'] = "The email address does not match the submitted user name";
+$messages['mailnomatch'] = "The email address does not match the submitted login";
 $messages['tokensent'] = "A confirmation email has been sent";
 $messages['tokensent_ifexists'] = "If the account exists, a confirmation email has been sent to the associated email address";
 $messages['tokennotsent'] = "Error when sending confirmation email";
@@ -108,8 +111,8 @@ $messages['notcomplex'] = "Your password does not have enough different classes
 $messages['policycomplex'] = "Minimum number of different classes of characters:";
 $messages['sms'] = "SMS number";
 $messages['smsresetmessage'] = "Your password reset token is:";
-$messages['sendsmshelp'] = "Enter your login to get password reset token. Then type token in sent SMS.";
 $messages['smssent'] = "A confirmation code has been send by SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Error when sending SMS";
 $messages['smsnonumber'] = "Can't find mobile number";
 $messages['userfullname'] = "User full name";
@@ -145,6 +148,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -153,3 +157,24 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token sent in SMS.";
+$messages['sendsmshelpnosms'] ="Enter your login to get password reset token. Then type token sent in SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
