@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP eguneratzea beharrezkoa da";
 $messages['nophpldap'] = "Webgune hau erabiltzeko PHP LDAP instalatu beharko duzu";
 $messages['nophpmhash'] = "Samba erabiltzeko PHP-ren mhash moduloa instalatu behar da";
 $messages['nokeyphrase'] = "Token-ak zifratzeko konfigurazioan ausazko esaldi bat idatzi behar duzu";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Ezin da LDAP direktorioa atzitu";
 $messages['loginrequired'] = "Ez duzu erabiltzaile izena idatzi";
 $messages['oldpasswordrequired'] = "Ez duzu pasahitz zaharra idatzi";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Ez duzu pasahitz berria idatzi";
 $messages['confirmpasswordrequired'] = "Pasahitz berria bi aldiz idatzi behar da";
 $messages['passwordchanged'] = "Zure pasahitza ondo eguneratu da";
 $messages['nomatch'] = "Pasahitz berria bi aldiz idatzi duzu baina ez dute kointziditzen";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Zure erabiltzaile izena edo pasahitz zaharra ez daude ondo";
 $messages['passworderror'] = "Zure pasahitz berria ez da onartu";
 $messages['title'] = "Pasahitza aldatzeko autozerbitzua";
@@ -99,8 +102,9 @@ $messages['notcomplex'] = "Zure pasahitzak ez dauka karaktere mota desberdin nah
 $messages['policycomplex'] = "Gutxienez behar direnak:";
 $messages['sms'] = "SMS Zenbakia";
 $messages['smsresetmessage'] = "Pasahitza berrezartzeko kodea hau da:";
-$messages['sendsmshelp'] = "Zure erabiltzaile izena idatzi pasahitza kode bidez berrezartzeko. Kodea SMS bidez iritsiko zaizu.";
+$messages['sendsmshelpnosms'] = "Zure erabiltzaile izena idatzi pasahitza kode bidez berrezartzeko. Kodea SMS bidez iritsiko zaizu.";
 $messages['smssent'] = "SMS bat bidali da kodearekin";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Errorea SMS-a bidaltzean";
 $messages['smsnonumber'] = "Telefono zenbakirik ez dago";
 $messages['userfullname'] = "Erabiltzailearen izen osoa";
@@ -146,6 +150,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -154,3 +159,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
