@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "Use mise à jour de PHP est requise";
 $messages['nophpldap'] = "Vous devriez installer PHP LDAP pour utiliser cet outil";
 $messages['nophpmhash'] = "Vous devriez installer PHP mhash pour utiliser le mode Samba";
 $messages['nokeyphrase'] = "Vous devez configurer keyphrase pour que le chiffrement fonctionne";
+$messages['nocrypttokens'] = "Les jetons chiffrés sont requis pour la fonctionnalité de réinitialisation par SMS";
+$messages['noreseturl'] = "La fonction de réinitialisation par mail nécessite de configurer l'URL de réinitialisation";
 $messages['ldaperror'] = "Erreur d'accès à l'annuaire";
 $messages['loginrequired'] = "Vous devez indiquer votre identifiant";
 $messages['oldpasswordrequired'] = "Vous devez indiquer votre ancien mot de passe";
@@ -33,13 +35,14 @@ $messages['newpasswordrequired'] = "Vous devez indiquer votre nouveau mot de pas
 $messages['confirmpasswordrequired'] = "Vous devez confirmer votre nouveau mot de passe";
 $messages['passwordchanged'] = "Votre mot de passe a été changé";
 $messages['nomatch'] = "Les mots de passe ne correspondent pas";
+$messages['insufficiententropy'] = "Entropie insuffisante pour le nouveau mot de passe";
 $messages['badcredentials'] = "Identifiant ou mot de passe incorrect";
 $messages['passworderror'] = "Le mot de passe a été refusé";
 $messages['title'] = "Gestion du mot de passe";
 $messages['login'] = "Identifiant";
 $messages['oldpassword'] = "Ancien mot de passe";
 $messages['newpassword'] = "Nouveau mot de passe";
-$messages['confirmpassword'] = "Confirmation";
+$messages['confirmpassword'] = "Confirmation du mot de passe";
 $messages['submit'] = "Envoyer";
 $messages['tooshort'] = "Votre mot de passe est trop court";
 $messages['toobig'] = "Votre mot de passe est trop long";
@@ -99,8 +102,9 @@ $messages['notcomplex'] = "Votre mot de passe n'a pas assez de classes de caract
 $messages['policycomplex'] = "Nombre minimum de classes de caractères :";
 $messages['sms'] = "Numéro SMS";
 $messages['smsresetmessage'] = "Votre jeton est:";
-$messages['sendsmshelp'] = "Entrez votre identifiant pour obtenir votre code de confirmation. Entrez ensuite le code reçu par SMS.";
+$messages['sendsmshelpnosms'] = "Entrez votre identifiant pour obtenir votre code de confirmation. Entrez ensuite le code reçu par SMS.";
 $messages['smssent'] = "Le code de confirmation a été envoyé par SMS.";
+$messages['smssent_ifexists'] = "Si ce compte existe, le code de confirmation a été envoyé par SMS.";
 $messages['smsnotsent'] = "Erreur lors de l'envoi du SMS";
 $messages['smsnonumber'] = "Le numéro de mobile n'a pas été trouvé.";
 $messages['userfullname'] = "Nom complet";
@@ -144,6 +148,7 @@ $messages['forbiddenwords'] = "Votre mot de passe contient des mots interdits";
 $messages['policyforbiddenwords'] = "Votre mot de passe ne doit pas contenir ::";
 $messages['forbiddenldapfields'] = "Votre mot de passe contient des valeurs de votre entrée LDAP";
 $messages['policyforbiddenldapfields'] = "Votre mot de passe ne doit pas contenir la valeur des attributs de votre entrée :";
+$messages['policyentropy'] = "Force du mot de passe";
 $messages['ldap_cn'] = "nom complet";
 $messages['ldap_givenName'] = "prénom";
 $messages['ldap_sn'] = "nom de famille";
@@ -153,3 +158,23 @@ $messages['badquality'] = "La qualité du mot de passe est insuffisante";
 $messages['tooyoung'] = "Le mot de passe a été changé trop récemment";
 $messages['inhistory'] = "Le mot de passe est déjà présent dans votre historique";
 $messages['throttle'] = "Trop de tentatives en trop peu de temps. Réessayez un peu plus tard (si vous êtes bien humain)";
+$messages['changecustompwdfieldhelp'] = "Pour changer votre mot de passe, vous devez rentrer votre mot de passe.";
+$messages['changehelpcustompwdfield'] = "Changez votre mot de passe pour ";
+$messages['newcustompassword'] = "nouveau mot de passe pour ";
+$messages['confirmcustompassword'] = "confirmez votre mot de passe";
+$messages['menucustompwdfield'] = "Mot de passe pour ";
+$messages['unknowncustompwdfield'] = "Le champ de mot de passe défini dans le lien ne peut être trouvé";
+$messages['sameascustompwd'] = "Le nouveau mot de passe n'est pas unique par rapport aux autres champs de mots de passe personnalisés";
+$messages['attributesmoderror'] = "La mise à jour de vos informations a échoué";
+$messages['attributeschanged'] = "Vos informations ont bien été modifiées";
+$messages['setattributeshelp'] = "Vous pouvez mettre à jour les informations utilisées lors d'une demande de réinitialisation de mot de passe. Entrez votre identifiant et votre mot de passe puis saisissez vos nouvelles coordonnées.";
+$messages['phone'] = "Numéro de téléphone";
+$messages['sendtokenhelpupdatemail'] = "Vous pouvez mettre à jour votre adresse email sur <a href=\"?action=setattributes\">cette page</a>.";
+$messages['sendsmshelpupdatephone'] = "Vous pouvez mettre à jour votre numéro de téléphone sur <a href=\"?action=setattributes\">cette page</a>.";
+$messages['sendsmshelp'] = "Entrez votre identifiant et votre numéro de téléphone pour obtenir votre code de confirmation. Entrez ensuite le code reçu par SMS.";
+$messages['smsrequired'] = "Vous devez indiquer votre numéro de téléphone.";
+$messages['smsnomatch'] = "Le numéro de téléphone ne correspond pas à l'identifiant donné.";
+$messages['sameasaccountpassword'] = "Votre nouveau mot de passe est identique à votre mot de passe de connexion";
+$messages['policynoreusecustompwdfield'] = "Votre nouveau mot de passe ne devrait pas être le même que le mot de passe de connexion";
+$messages['missingformtoken'] = "Jeton manquant";
+$messages['invalidformtoken'] = "Jeton invalide";
