@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP frissítés szükséges";
 $messages['nophpldap'] = "A program használatához telepíteni kell a PHP LDAP csomagot";
 $messages['nophpmhash'] = "A Samba üzemmód használatához telepíteni kell a PHP mhash csomagot";
 $messages['nokeyphrase'] = "A token titkosításához random stringre van szükség";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Nem érhető el az LDAP szolgáltatás";
 $messages['loginrequired'] = "A felhasználónév megadása kötelező!";
 $messages['oldpasswordrequired'] = "A régi jelszó megadása kötelező!";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Az új jelszó megadása kötelező!";
 $messages['confirmpasswordrequired'] = "Kérem, hagyja jóvá az új jelszavát!";
 $messages['passwordchanged'] = "A jelszó sikeresen megváltozott!";
 $messages['nomatch'] = "A beírt új jelszavak nem egyeznek meg!";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "A felhasználónév vagy a jelszó nem megfelelő!";
 $messages['passworderror'] = "A jelszó megváltoztatását visszautasította az LDAP szolgáltatás";
 $messages['title'] = "Önkiszolgáló jelszókezelő";
@@ -100,8 +103,9 @@ $messages['notcomplex'] = "A jelszó nem elég komplex. Kérem, használjon kis-
 $messages['policycomplex'] = "A jelszó a következő karaktertípusokat tartalmazhatja: kisbetű, nagybetű, szám vagy speciális karakter. Ezek közül válasszon ki legalább ennyit:";
 $messages['sms'] = "SMS szám";
 $messages['smsresetmessage'] = "Jelszava megváltoztatásához írja be az alábbi kódot:";
-$messages['sendsmshelp'] = "Írja be felhasználónevét, majd az SMS-ben kapott aktiváló kódot.";
+$messages['sendsmshelpnosms'] = "Írja be felhasználónevét, majd az SMS-ben kapott aktiváló kódot.";
 $messages['smssent'] = "Aktiváló kód SMS-ben kiküldve";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Hiba az SMS küldése közben";
 $messages['smsnonumber'] = "Mobilszám nem található";
 $messages['userfullname'] = "Teljes név";
@@ -145,6 +149,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -153,3 +158,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
