@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP upgrade vereist";
 $messages['nophpldap'] = "PHP LDAP moet geinstalleerd zijn om deze tool te kunnen gebruiken";
 $messages['nophpmhash'] = "PHP mhash moet geinstalleerd zijn om Samba mode te kunnen gebruiken";
 $messages['nokeyphrase'] = "Token encryptie vereist een willekeurige string in de keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Kan geen toegang tot de LDAP directory verkrijgen";
 $messages['loginrequired'] = "Gebruikersnaam is vereist";
 $messages['oldpasswordrequired'] = "Huidige wachtwoord is een verplicht veld";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Nieuwe wachtwoord is een verplicht veld";
 $messages['confirmpasswordrequired'] = "Bevestig het nieuwe wachtwoord";
 $messages['passwordchanged'] = "Het wachtwoord is gewijzigd";
 $messages['nomatch'] = "Nieuwe wachtwoord en Bevestigen zijn ongelijk";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Gebruikersnaam of wachtwoord onjuist";
 $messages['passworderror'] = "Wachtwoord niet geaccepteerd door de LDAP directory";
 $messages['title'] = "Wachtwoord Self Service";
@@ -99,8 +102,9 @@ $messages['notcomplex'] = "Uw wachtwoord bestaat niet uit genoeg verschillende t
 $messages['policycomplex'] = "Minimum aantal verschillende type tekens benodigd:";
 $messages['sms'] = "Mobiele telefoon";
 $messages['smsresetmessage'] = "Uw wachtwoord reset token is:";
-$messages['sendsmshelp'] = "Voer uw login informatie in om uw wachtwoord reset token te ontvangen. Voer vervolgens het token in wat toegestuurd is via SMS.";
+$messages['sendsmshelpnosms'] = "Voer uw login informatie in om uw wachtwoord reset token te ontvangen. Voer vervolgens het token in wat toegestuurd is via SMS.";
 $messages['smssent'] = "Een bevestigingscode is verzonden via SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Fout tijdens het versturen van een SMS";
 $messages['smsnonumber'] = "Mobiele nummer niet gevonden";
 $messages['userfullname'] = "Volledige naam van gebruiker";
@@ -147,6 +151,7 @@ $messages['forbiddenwords'] = "Uw wachtwoord bevat verboden woorden of strings";
 $messages['policyforbiddenwords'] = "In uw wachtwoord mag niet hetvolgende voorkomen:";
 $messages['forbiddenldapfields'] = "Uw wachtwoord mag geen gegevens bevatten uit uw LDAP";
 $messages['policyforbiddenldapfields'] = "Uw wachtwoord mag geen waardes bevatten van de volgende LDAP velden:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -155,3 +160,23 @@ $messages["questionspopulatehint"] = "Vul enkel uw login in om je geregistreede
 $messages['badquality'] = "Wachtwoord is niet sterk genoeg";
 $messages['tooyoung'] = "Wachtwoord is te recent aangepast";
 $messages['inhistory'] = "Wachtwoord zit in wachtwoord geschiedenis";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
