@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "Wymagana aktualizacja PHP";
 $messages['nophpldap'] = "Wymagane jest zainstalowanie PHP-LDAP zanim użyjesz tego narzędzia";
 $messages['nophpmhash'] = "Wymagane jest zainstalowanie PHP-mhash przed użyciem trybu Samba";
 $messages['nokeyphrase'] = "Szyfrowanie Tokena wymaga losowego ciągu keyphrase w konfiguracji";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Nie można połączyć się z bazą LDAP";
 $messages['loginrequired'] = "Wymagany jest Twój login";
 $messages['oldpasswordrequired'] = "Wymagane jest Twoje stare hasło";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Wymagane jest Twoje nowe hasło";
 $messages['confirmpasswordrequired'] = "Potwierdź proszę Twoje nowe hasło";
 $messages['passwordchanged'] = "Twoje hasło zostało zmienione";
 $messages['nomatch'] = "Hasła nie są zgodne";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Login lub hasło nie są poprawne";
 $messages['passworderror'] = "Hasło zostało odrzucone przez bazę LDAP";
 $messages['title'] = "Samodzielna zmiana hasła";
@@ -101,8 +104,9 @@ $messages['notcomplex'] = "Twoje hasło nie posiada wystarczającej liczby róż
 $messages['policycomplex'] = "Hasło musi się składać z (minimalna liczba) następujących rodzajów znaków:";
 $messages['sms'] = "Numer SMS";
 $messages['smsresetmessage'] = "Twój Token resetowania hasła to:";
-$messages['sendsmshelp'] = "Wprowadź swój login, aby otrzymać Token resetowania hasła. Następnie wpisz token w wysłanej wiadomości SMS.";
+$messages['sendsmshelpnosms'] = "Wprowadź swój login, aby otrzymać Token resetowania hasła. Następnie wpisz token w wysłanej wiadomości SMS.";
 $messages['smssent'] = "Kod potwierdzający został wysłany SMS-em";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Błąd podczas wysyłania wiadomości SMS";
 $messages['smsnonumber'] = "Nie znaleziono numeru telefonu komórkowego";
 $messages['userfullname'] = "Pełna nazwa użytkownika";
@@ -146,6 +150,7 @@ $messages['forbiddenwords'] = "Twoje hasła zawierają zabronione słowa lub ci
 $messages['policyforbiddenwords'] = "Twoje hasło nie może zawierać:";
 $messages['forbiddenldapfields'] = "Twoje hasło zawiera wartości z wpisu LDAP";
 $messages['policyforbiddenldapfields'] = "Twoje hasło nie może zawierać wartości z następujących pól LDAP:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "nazwa";
 $messages['ldap_givenName'] = "imię";
 $messages['ldap_sn'] = "nazwisko";
@@ -155,3 +160,23 @@ $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
 $messages['throttle'] = "Too fast! Please try again later (if ever you are human)";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
