@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,10 +22,12 @@
 #==============================================================================
 # Português Brasileiro
 #==============================================================================
-$messages['phpupgraderequired'] = "O seu PHP necessita de upgrade";
+$messages['phpupgraderequired'] = "O seu PHP necessita de atualização";
 $messages['nophpldap'] = "Você deve instalar o PHP LDAP para utilizar esta ferramenta";
-$messages['nophpmhash'] = "Você deve instalar o PHP mhash para utilizar o Samba mode";
+$messages['nophpmhash'] = "Você deve instalar o PHP mhash para utilizar o modo Samba";
 $messages['nokeyphrase'] = "Criptografia do Token necessita de uma string aleatória nas configuração de keyphrase";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Não foi possível acessar o diretório LDAP";
 $messages['loginrequired'] = "O seu nome de usuário é necessário";
 $messages['oldpasswordrequired'] = "A senha atual é necessária";
@@ -34,6 +36,7 @@ $messages['confirmpasswordrequired'] = "Confirme a nova senha";
 $messages['passwordchanged'] = "A senha foi alterada";
 $messages['sshkeychanged'] = "Sua chave SSH foi alterada";
 $messages['nomatch'] = "As senhas não coincidem";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Nome de usuário ou senha incorretos";
 $messages['passworderror'] = "A senha foi recusada pelo Diretório LDAP";
 $messages['sshkeyerror'] = "A chave SSH foi recusada pelo diretório LDAP";
@@ -50,12 +53,12 @@ $messages['minlower'] = "A senha não contém letras minúsculas suficientes";
 $messages['minupper'] = "A senha não contém letras maiúsculas suficientes";
 $messages['mindigit'] = "A senha não contém caracteres suficientes";
 $messages['minspecial'] = "A senha não contém caracteres especiais";
-$messages['sameasold'] = "A senha nova é igual a senha atual";
+$messages['sameasold'] = "A senha nova é igual à senha atual";
 $messages['policy'] = "A senha deve respeitar as regras de restrição:";
 $messages['policyminlength'] = "Tamanho mínimo: ";
 $messages['policymaxlength'] = "Tamanho máximo: ";
 $messages['policyminlower'] = "Mínimo de letras minúsculas: ";
-$messages['policyminupper'] = "Máximo de letras maiúsculas: ";
+$messages['policyminupper'] = "Mínimo de letras maiúsculas: ";
 $messages['policymindigit'] = "Mínimo de números: ";
 $messages['policyminspecial'] = "Mínimo de caracteres especiais: ";
 $messages['forbiddenchars'] = "A senha contém caracteres proibidos";
@@ -66,12 +69,12 @@ $messages['questions']['color'] = "Qual é a sua cor favorita?";
 $messages['password'] = "Senha";
 $messages['question'] = "Pergunta";
 $messages['answer'] = "Resposta";
-$messages['setquestionshelp'] = "Inicializar ou mudar a tua pergunta/resposta de redefinição de senha. Você pode então resetar a tua senha <a href=\"?action=resetbyquestions\">here</a>.";
+$messages['setquestionshelp'] = "Inicializar ou mudar a tua pergunta/resposta de redefinição de senha. Você pode então resetar a tua senha <a href=\"?action=resetbyquestions\">aqui</a>.";
 $messages['answerrequired'] = "Sem resposta";
 $messages['questionrequired'] = "Nenhuma pergunta selecionada";
 $messages['passwordrequired'] = "A senha é necessária";
 $messages['sshkeyrequired'] = "A chave SSH é necessária";
-$messages['invalidsshkey'] = "Input SSH Key looks invalid";
+$messages['invalidsshkey'] = "A chave SSH de entrada parece inválida";
 $messages['answermoderror'] = "A resposta não foi registrada";
 $messages['answerchanged'] = "A resposta foi registrada";
 $messages['answernomatch'] = "A resposta está incorreta";
@@ -91,25 +94,26 @@ $messages['mail'] = "E-mail";
 $messages['mailrequired'] = "O e-mail é necessário";
 $messages['mailnomatch'] = "O e-mail não coincide com nenhum usuário";
 $messages['tokensent'] = "O e-mail de confirmação foi enviado";
-$messages['tokensent_ifexists'] = "If the account exists, a confirmation email has been sent to the associated email address";
+$messages['tokensent_ifexists'] = "Se a conta existe, um email de confirmação foi enviado para o endereço de email associado";
 $messages['tokennotsent'] = "Erro durante o envio do e-mail de confirmação";
 $messages['tokenrequired'] = "O código é necessário";
 $messages['tokennotvalid'] = "Código inválido";
 $messages['resetbytokenhelp'] = "O código enviado por e-mail permite que você redefina a senha. Para enviar um novo código, <a href=\"?action=sendtoken\">Clique aqui</a>.";
-$messages['resetbysmshelp'] = "O token enviado por sms permite você alterar sua senha. Para recer um novo token, <a href=\"?action=sendsms\">clique aqui</a>.";
-$messages['changemessage'] = "Olá {login},\n\nSua senha foi alterada.\n\nSe você não solicitou esta requisição, por favor contacte seu administrador imediatamente.";
+$messages['resetbysmshelp'] = "O token enviado por SMS permite você alterar sua senha. Para recer um novo token, <a href=\"?action=sendsms\">clique aqui</a>.";
+$messages['changemessage'] = "Olá {login},\n\nSua senha foi alterada.\n\nSe você não solicitou esta requisição, por favor contate seu administrador imediatamente.";
 $messages['changesubject'] = "Sua senha foi alterada";
-$messages['changesshkeymessage'] = "Olá {login},\n\nSua chave SSH Key foi alterada.\n\nSe você não solicitou esta troca, por favor contacte seu administrador imediatamente..";
+$messages['changesshkeymessage'] = "Olá {login},\n\nSua chave SSH Key foi alterada.\n\nSe você não solicitou esta troca, por favor contacte seu administrador imediatamente.";
 $messages['changesshkeysubject'] = "Sua chave SSH foi alterada";
 $messages['badcaptcha'] = "O captcha não foi digitado corretamente. Tente novamente.";
-$messages['captcharequired'] = "The captcha is required.";
+$messages['captcharequired'] = "O captcha é necessário.";
 $messages['captcha'] = "Captcha";
 $messages['notcomplex'] = "Sua senha não possui diferentes tipos de caracteres suficientes para torná-la complexa";
 $messages['policycomplex'] = "Quantidade mínima de tipos de caracteres: ";
 $messages['sms'] = "Número SMS";
 $messages['smsresetmessage'] = "Seu código para redefinir a senha é:";
-$messages['sendsmshelp'] = "Informe seu nome de usuário para obter o código para redefinir sua senha. Depois digite o código enviado no SMS.";
+$messages['sendsmshelpnosms'] = "Informe seu nome de usuário para obter o código para redefinir sua senha. Depois digite o código enviado no SMS.";
 $messages['smssent'] = "Um código de confirmação foi enviado via SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Erro ao enviar SMS";
 $messages['smsnonumber'] = "Não foi possível encontrar o número";
 $messages['userfullname'] = "Nome completo";
@@ -134,24 +138,43 @@ $messages['emptysendsmsform'] = "Receba um código para alteração de senha";
 $messages['sameaslogin'] = "Sua nova senha é idêntica ao seu nome de usuário";
 $messages['policydifflogin'] = "Sua nova senha não pode ser igual ao seu nome de usuário";
 $messages['pwned'] = "Sua nova senha já foi publicada como vazada, você deveria alterá-la em qualquer outro site que a utilize.";
-$messages['policypwned'] = "Parece que sua nova senha não foi publicada como vazada de qualquer site";
-$messages['throttle'] = "Too fast! Please try again later (if ever you are human)";
-$messages['policydiffminchars'] = "Minimum number of new unique characters:";
-$messages['diffminchars'] = "Your new password is too similar to your old password";
+$messages['policypwned'] = "Sua nova senha não pode ter sido publicada como vazada de qualquer site";
+$messages['throttle'] = "Rápido demais! Por favor tente novamente depois (se você for humano)";
+$messages['policydiffminchars'] = "Número mínimo de novos caracteres únicos:";
+$messages['diffminchars'] = "Sua nova senha é muito similar à sua senha antiga";
 $messages['specialatends'] = "Sua nova senha tem o único caracter especial no início ou fim";
 $messages['policyspecialatends'] = "Sua nova senha pode não ter o único caracter especial no início ou fim";
-$messages['checkdatabeforesubmit'] = "Please check your information before submitting the form";
-$messages['specialatends'] = "Your new password has its only special character at the beginning or end";
-$messages['policyspecialatends'] = "Your new password may not have its only special character at the beginning or end";
-$messages['forbiddenwords'] = "Your passwords contains forbidden words or strings";
-$messages['policyforbiddenwords'] = "Your password must not contain:";
-$messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
-$messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
-$messages['ldap_cn'] = "common name";
-$messages['ldap_givenName'] = "given name";
-$messages['ldap_sn'] = "surname";
-$messages['ldap_mail'] = "mail address";
-$messages["questionspopulatehint"] = "Enter only your login to retrieve the questions you've registered.";
-$messages['badquality'] = "Password quality is too low";
-$messages['tooyoung'] = "Password was changed too recently";
-$messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['checkdatabeforesubmit'] = "Por favor verifique suas informações antes de submeter o formulário";
+$messages['forbiddenwords'] = "Suas senhas contêm palavras ou strings proibidas";
+$messages['policyforbiddenwords'] = "Sua senha não deve conter:";
+$messages['forbiddenldapfields'] = "Sua senha contém valores do seu cadastro LDAP";
+$messages['policyforbiddenldapfields'] = "Sua senha não pode conter valores dos seguintes campos LDAP:";
+$messages['policyentropy'] = "Password strength";
+$messages['ldap_cn'] = "nome de usuário";
+$messages['ldap_givenName'] = "primeiro nome";
+$messages['ldap_sn'] = "sobrenome";
+$messages['ldap_mail'] = "endereço de email";
+$messages["questionspopulatehint"] = "Entre apenas o seu login para obter as perguntas que você registrou.";
+$messages['badquality'] = "A qualidade da senha é muito baixa";
+$messages['tooyoung'] = "A senha foi alterada muito recentemente";
+$messages['inhistory'] = "A senha está no histórico de senhas antigas";
+$messages['attributesmoderror'] = "Suas informações não foram atualizadas";
+$messages['attributeschanged'] = "Suas informações foram atualizadas";
+$messages['setattributeshelp'] = "Você pode atualizar as informações usadas para redefinir sua senha. Entre seu login e senha e defina seus novos detalhes.";
+$messages['phone'] = "Número de telefone";
+$messages['sendtokenhelpupdatemail'] = "Você pode atualizar seu endereço de email <a href=\"?action=setattributes\">nesta página</a>.";
+$messages['sendsmshelpupdatephone'] = "Você pode atualizar seu número de telefone <a href=\"?action=setattributes\">nesta página</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
