@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP upgrade required";
 $messages['nophpldap'] = "Necessitas de instalar o PHP LDAP para utilizares esta ferramenta.";
 $messages['nophpmhash'] = "Necessitas de instalar o PHP mhash para utilizares o Samba mode.";
 $messages['nokeyphrase'] = "Token encryption requires a random string in keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Não foi possivel aceder à pasta LDAP.";
 $messages['loginrequired'] = "O teu username é necessário.";
 $messages['oldpasswordrequired'] = "A password atual é necessária.";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "A nova password é necessária.";
 $messages['confirmpasswordrequired'] = "Confirma a nova password.";
 $messages['passwordchanged'] = "A password foi alterada.";
 $messages['nomatch'] = "As passwords não coincidem.";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Username ou password incorretos.";
 $messages['passworderror'] = "A password foi recusada pelo LDAP.";
 $messages['title'] = "Alteração de Password";
@@ -98,8 +101,9 @@ $messages['notcomplex'] = "A tua password não possui diferentes tipos de carác
 $messages['policycomplex'] = "Quantidade mínima de tipos de carácteres: ";
 $messages['sms'] = "Número SMS";
 $messages['smsresetmessage'] = "O teu código para redefinir a password é:";
-$messages['sendsmshelp'] = "Indica o teu username para obteres o código para redefinir a tua password. Depois digita o código enviado por SMS.";
+$messages['sendsmshelpnosms'] = "Indica o teu username para obteres o código para redefinir a tua password. Depois digita o código enviado por SMS.";
 $messages['smssent'] = "Um código de confirmação foi enviado via SMS.";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Erro ao enviar SMS.";
 $messages['smsnonumber'] = "Nao foi possível encontrar o teu número de telemóvel.";
 $messages['userfullname'] = "Nome completo";
@@ -145,6 +149,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -153,3 +158,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
