@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "Potrbno je ažuriranje PHP-a";
 $messages['nophpldap'] = "Potrebno je instalirati PHP LDAP da bi ste koristili ovu alatku";
 $messages['nophpmhash'] = "Potrebno je instalirati PHP mhash da bi ste koristili SAMBA mod";
 $messages['nokeyphrase'] = "Enkripcija Tokena zahteva nasumičan niz karaktera u podešavanju keyphrase-a";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Ne mogu da pristupim LDAP direktorijumu";
 $messages['loginrequired'] = "Potrebno je vaše korisničko ime";
 $messages['oldpasswordrequired'] = "Potrebna je Vaša stara lozinka";
@@ -34,6 +36,7 @@ $messages['confirmpasswordrequired'] = "Molim Vas potvrdite Vašu novu lozinku";
 $messages['passwordchanged'] = "Vaša lozinka je izmenjena";
 $messages['sshkeychanged'] = "Vaš SSH ključ je izmenjen";
 $messages['nomatch'] = "Ne poklapaju se lozinke";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Korisničko ime ili lozinka su netačni";
 $messages['passworderror'] = "Lozinka odbijena od strane LDAP direktorijuma";
 $messages['sshkeyerror'] = "SSH ključ odbijen od strane LDAP direktorijuma";
@@ -108,8 +111,9 @@ $messages['notcomplex'] = "Vaša lozinka nema dovoljno različitih vrsta karakte
 $messages['policycomplex'] = "Minimalan broj različitih vrsta karaktera:";
 $messages['sms'] = "Broj telefona za SMS";
 $messages['smsresetmessage'] = "Vaš token za resetovanje lozinke je:";
-$messages['sendsmshelp'] = "Unesite svoje korisničko ime da dobijete token za resetovanje lozinke. Zatim ukucajte token koji ćete dobiti SMS-om.";
+$messages['sendsmshelpnosms'] = "Unesite svoje korisničko ime da dobijete token za resetovanje lozinke. Zatim ukucajte token koji ćete dobiti SMS-om.";
 $messages['smssent'] = "Vaš token je poslat SMS-om";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "Greška prilikom slanja SMS-a";
 $messages['smsnonumber'] = "Nema broja mobilnog telefona";
 $messages['userfullname'] = "Puno ime korisnika";
@@ -145,6 +149,7 @@ $messages['forbiddenwords'] = "Vaša lozinka sadrži zabranjene reči ili nizove
 $messages['policyforbiddenwords'] = "Vaša lozinka ne sme da sadrži:";
 $messages['forbiddenldapfields'] = "Vaša lozinka sadrži vrednosti iz LDAP unosa";
 $messages['policyforbiddenldapfields'] = "Vaša lozinka ne sme da sadrži vrednosti iz sledećih LDAP vrednosti:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "nadimak";
 $messages['ldap_givenName'] = "ime";
 $messages['ldap_sn'] = "prezime";
@@ -153,3 +158,23 @@ $messages['questionspopulatehint'] = "Unesite samo korisničko ime da bi ste pro
 $messages['badquality'] = "Kvalitet Vaše lozinke je veoma nizak";
 $messages['tooyoung'] = "Lozinka je skorije menjana";
 $messages['inhistory'] = "Lozinka je u istoriji starih lozinki";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
