@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP güncellemesi gerekli";
 $messages['nophpldap'] = "Bu aracı kullanabilmek için PHP LDAP yüklemelisiniz";
 $messages['nophpmhash'] = "Samba modunu kullanmak için PHP mhash yüklemelisiniz";
 $messages['nokeyphrase'] = "Belirteç şifrelemesi için keyphrase ayarında rastgele bir metin olması gerekir";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "LDAP dizinine ulaşılamıyor";
 $messages['loginrequired'] = "Kullanıcı adınız gereklidir";
 $messages['oldpasswordrequired'] = "Eski parolanız gereklidir";
@@ -33,6 +35,7 @@ $messages['newpasswordrequired'] = "Yeni parolanız gereklidir";
 $messages['confirmpasswordrequired'] = "Lütfen yeni parolanızı doğrulayın";
 $messages['passwordchanged'] = "Parolanız değiştirildi";
 $messages['nomatch'] = "Parolalar uyuşmuyor";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Kullanıcı adı ya da parola hatalı";
 $messages['passworderror'] = "Parola LDAP dizini tarafından reddedildi";
 $messages['title'] = "Self servis parola";
@@ -85,7 +88,7 @@ $messages['mail'] = "E-posta adresi";
 $messages['mailrequired'] = "E-posta adresiniz gereklidir";
 $messages['mailnomatch'] = "E-posta adresi ile kullanıcı adı uyuşmuyor";
 $messages['tokensent'] = "Doğrulama e-postası gönderildi";
-$messages['tokensent_ifexists'] = "If the account exists, a confirmation email has been sent to the associated email address";
+$messages['tokensent_ifexists'] = "Eğer hesap mevcutsa bir doğrulama e-postası hesaba ilişkili e-posta adresine gönderilmiştir";
 $messages['tokennotsent'] = "Doğrulama e-postası gönderilirken hata oluştu";
 $messages['tokenrequired'] = "Belirteç gerekli";
 $messages['tokennotvalid'] = "Belirteç geçerli değil";
@@ -100,8 +103,9 @@ $messages['notcomplex'] = "Parolanız yeterli sayıda değişik sınıf karakter
 $messages['policycomplex'] = "Minimum değişik karakter sınıfı sayısı:";
 $messages['sms'] = "SMS numarası";
 $messages['smsresetmessage'] = "Parola sıfırlama belirteciniz:";
-$messages['sendsmshelp'] = "SMS almak için kullanıcı adınızı, sonrasında da SMS ile yollanan belirteci girin.";
+$messages['sendsmshelpnosms'] = "SMS almak için kullanıcı adınızı, sonrasında da SMS ile yollanan belirteci girin.";
 $messages['smssent'] = "SMS ile bir doğrulama kodu gönderildi";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "SMS gönderilirken hata oluştu";
 $messages['smsnonumber'] = "Mobil numara bulunamıyor";
 $messages['userfullname'] = "Kullanıcının tam adı";
@@ -145,6 +149,7 @@ $messages['forbiddenwords'] = "Parolanız yasaklı kelimeler içeriyor";
 $messages['policyforbiddenwords'] = "Parolanız bunu içeremez:";
 $messages['forbiddenldapfields'] = "Parolanız LDAP girdinizden bilgiler içeriyor";
 $messages['policyforbiddenldapfields'] = "Parolanız bu LDAP alanlarından değerler içeremez:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "yerel ad";
 $messages['ldap_givenName'] = "verilen ad";
 $messages['ldap_sn'] = "soyad";
@@ -153,3 +158,23 @@ $messages["questionspopulatehint"] = "Daha önceden girdiğiniz soruları yükle
 $messages['badquality'] = "Parola kaliteniz çok düşük";
 $messages['tooyoung'] = "Parolanız çok kısa bir süre önce değiştirildi";
 $messages['inhistory'] = "Parola geçmiş parolalarınız arasında yer alıyor";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Bilgileriniz güncellenmedi";
+$messages['attributeschanged'] = "Bilgileriniz güncellendi";
+$messages['setattributeshelp'] = "Parolanızı sıfırlamak için kullanılan bilgileri güncelleyebilirsiniz. Kullanıcı adınız ile parolanızı girin ve yeni bilgilerinizi belirleyin.";
+$messages['phone'] = "Telefon numarası";
+$messages['sendtokenhelpupdatemail'] = "E-posta adresinizi <a href=\"?action=setattributes\">bu sayfada</a> güncelleyebilirsiniz.";
+$messages['sendsmshelpupdatephone'] = "Telefon numaranızı <a href=\"?action=setattributes\">bu sayfada</a> güncelleyebilirsiniz.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
