@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 # Copyright (C) 2016 Oleh Kravchenko <oleg@kaa.org.ua>
 #
 # This program is free software; you can redistribute it and/or
@@ -27,6 +27,8 @@ $messages['phpupgraderequired'] = "PHP upgrade required";
 $messages['nophpldap'] = "Для використання цієї програми Вам потрібно встановити PHP ldap";
 $messages['nophpmhash'] = "Для використання Samba режиму, спочатку встановіть PHP mhash";
 $messages['nokeyphrase'] = "Token encryption requires a random string in keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "Немає доступу до LDAP директорії";
 $messages['loginrequired'] = "Введіть Ваш логін";
 $messages['oldpasswordrequired'] = "Введіть Ваш старий пароль";
@@ -34,6 +36,7 @@ $messages['newpasswordrequired'] = "Введіть Ваш новий парол
 $messages['confirmpasswordrequired'] = "Повторіть Ваш новий пароль";
 $messages['passwordchanged'] = "Ваш пароль змінено";
 $messages['nomatch'] = "Перевірте правильність написання пароля";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "Перевірте правильність написання логіна або пароля";
 $messages['passworderror'] = "Ваш пароль відхилено LDAP директорією";
 $messages['title'] = "Self service password";
@@ -103,12 +106,13 @@ $messages['sms'] = "SMS номер";
 $messages['smstoken'] = "SMS жетон";
 $messages['smsnonumber'] = "Не можу знайти номер мобільного телефону";
 $messages['username'] = "Користувач";
-$messages['sendsmshelp'] = "Введіть свій логін, щоб отримати жетон скидання пароля. Потім введіть жетон в відправлених SMS.";
+$messages['sendsmshelpnosms'] = "Введіть свій логін, щоб отримати жетон скидання пароля. Потім введіть жетон в відправлених SMS.";
 $messages['changehelpsms'] = "<a href=\"?action=sendsms\">Скинути ваш пароль за допомогою SMS</a>";
 $messages['userfullname'] = "Повне ім'я";
 $messages['getuser'] = "Отримати користувача";
 $messages['resetbysmshelp'] = "Жетон який дозволяє скинути пароль, відправлено через SMS. Щоб отримати новий жетон, <a href=\"?action=sendsms\">клацніть тут</a>.";
 $messages['smssent'] = "Код підтвердження був відправлений через SMS";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsuserfound'] = "Перевірте, що інформація про користувача вірна та натисніть «Відправити SMS», щоб отримати жетон";
 $messages['nophpmbstring'] = "Ви повинні встановити PHP mbstring";
 $messages['menuquestions'] = "Question";
@@ -146,6 +150,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -154,3 +159,23 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
