@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "请升级 PHP 版本";
 $messages['nophpldap'] = "您需要安装 PHP LDAP 才能使用本工具";
 $messages['nophpmhash'] = "您需要安装 PHP mhash 才能使用 Samba 模式";
 $messages['nokeyphrase'] = "在使用凭据加密前，需要在 keyphrase 设置中填写一个随机字符串";
+$messages['nocrypttokens'] = "未设置 crypt_tokens 不能使用短信重置";
+$messages['noreseturl'] = "未设置 reset_url 不能使用邮箱重置";
 $messages['ldaperror'] = "不能访问 LDAP 目录服务";
 $messages['loginrequired'] = "请输入您的用户名";
 $messages['oldpasswordrequired'] = "请输入您的旧密码";
@@ -34,6 +36,7 @@ $messages['confirmpasswordrequired'] = "请确认您的新密码";
 $messages['passwordchanged'] = "您的密码已修改";
 $messages['sshkeychanged'] = "您的 SSH 密钥已更改";
 $messages['nomatch'] = "密码不一致";
+$messages['insufficiententropy'] = "新的密码缺乏安全性";
 $messages['badcredentials'] = "用户名或密码不正确";
 $messages['passworderror'] = "密码被 LDAP 目录服务拒绝";
 $messages['sshkeyerror'] = "SSH 密钥被 LDAP 目录服务拒绝";
@@ -91,7 +94,7 @@ $messages['mail'] = "邮箱";
 $messages['mailrequired'] = "请输入您的邮箱地址";
 $messages['mailnomatch'] = "邮箱地址与已提交用户名对应的邮箱地址不一致";
 $messages['tokensent'] = "已发送重置密码邮件";
-$messages['tokensent_ifexists'] = "If the account exists, a confirmation email has been sent to the associated email address";
+$messages['tokensent_ifexists'] = "如果用户信息正确，您将收到重置密码邮件";
 $messages['tokennotsent'] = "发送重置密码邮件时出现错误";
 $messages['tokenrequired'] = "请提供凭据";
 $messages['tokennotvalid'] = "凭据无效";
@@ -108,8 +111,8 @@ $messages['notcomplex'] = "您的密码没有包含足够的不同字符类型";
 $messages['policycomplex'] = "最少不同字符类型数量：";
 $messages['sms'] = "短信号码";
 $messages['smsresetmessage'] = "您的密码重置口令：";
-$messages['sendsmshelp'] = "输入您的用户名获取密码重置短信。然后输入短信中的口令。";
 $messages['smssent'] = "口令短信已发送";
+$messages['smssent_ifexists'] = "如果用户信息正确，您将收到重置密码短信";
 $messages['smsnotsent'] = "短信发送错误";
 $messages['smsnonumber'] = "未发现手机号码";
 $messages['userfullname'] = "用户全名";
@@ -133,11 +136,11 @@ $messages['emptysetquestionsform'] = "设置您的密码重置问题";
 $messages['emptysendsmsform'] = "获取重置口令";
 $messages['sameaslogin'] = "您的新密码与您的用户名相同";
 $messages['policydifflogin'] = "您的新密码不能与您的用户名相同";
-$messages['pwned'] = "Your new password has already been published on leaks, you should consider changing it on any other service that it is in use";
-$messages['policypwned'] = "Your new password may not be published on any previous public password leak from any site";
+$messages['pwned'] = "您提供的新密码在泄露的密码列表中，您应不应该在任何地方使用它";
+$messages['policypwned'] = "您提供的密码不应在泄漏的密码列表中";
 $messages['throttle'] = "太快了！请稍后再试（如果真的是您手动操作）";
 $messages['policydiffminchars'] = "最少新增不重复字符个数：";
-$messages['diffminchars'] = "你的新密码与旧密码过于相似";
+$messages['diffminchars'] = "您的新密码与旧密码过于相似";
 $messages['specialatends'] = "您的新密码以特殊字符开头或结尾";
 $messages['policyspecialatends'] = "您的新密码不能以特殊字符开头或结尾";
 $messages['checkdatabeforesubmit'] = "在提交表单前，请核对您的信息";
@@ -145,11 +148,33 @@ $messages['forbiddenwords'] = "您的密码包含禁止词语或字串";
 $messages['policyforbiddenwords'] = "您的密码必须不包含：";
 $messages['forbiddenldapfields'] = "您的密码包含来自您的 LDAP 条目中的内容";
 $messages['policyforbiddenldapfields'] = "您的密码不能包含来自下列 LDAP 条目中的内容：";
+$messages['policyentropy'] = "密码强度";
 $messages['ldap_cn'] = "姓名";
 $messages['ldap_givenName'] = "名";
 $messages['ldap_sn'] = "姓";
 $messages['ldap_mail'] = "邮箱地址";
-$messages["questionspopulatehint"] = "Enter only your login to retrieve the questions you've registered.";
-$messages['badquality'] = "密码质量太低";
-$messages['tooyoung'] = "Password was changed too recently";
-$messages['inhistory'] = "Password is in history of old passwords";
+$messages["questionspopulatehint"] = "输入用户名查看已经设置的密码重置问题";
+$messages['badquality'] = "密码强度太低";
+$messages['tooyoung'] = "密码修改间隔太短";
+$messages['inhistory'] = "这个是一个旧密码";
+$messages['changecustompwdfieldhelp'] = "修改密码，您需要提供旧密码";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "您的信息没有更新";
+$messages['attributeschanged'] = "您的信息已更新";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "手机号码";
+$messages['sendtokenhelpupdatemail'] = "您可以通过<a href=\"?action=setattributes\">这个页面</a>更新邮箱地址.";
+$messages['sendsmshelpupdatephone'] = "您可以通过<a href=\"?action=setattributes\">这个页面</a>更新手机号码.";
+$messages['sendsmshelpnosms'] = "输入您的用户名获取密码重置短信。然后输入短信中的口令。";
+$messages['sendsmshelp'] = "输入您的用户名和手机号码获取密码重置短信。然后输入短信中的口令。";
+$messages['smsrequired'] = "手机号码是必须的";
+$messages['smsnomatch'] = "用户名和手机号码不匹配";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
