@@ -2,8 +2,8 @@
 #==============================================================================
 # LTB Self Service Password
 #
-# Copyright (C) 2009 Clement OUDOT
-# Copyright (C) 2009 LTB-project.org
+# Copyright (C) 2024 Clement OUDOT
+# Copyright (C) 2024 LTB-project.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,8 @@ $messages['phpupgraderequired'] = "PHP 版本需要更新";
 $messages['nophpldap'] = "您需要安裝 PHP LDAP 才能使用此工具";
 $messages['nophpmhash'] = "您需要安裝 PHP mhash 才能使用 Samba 模式";
 $messages['nokeyphrase'] = "Token encryption requires a random string in keyphrase setting";
+$messages['nocrypttokens'] = "Crypted tokens are mandatory for reset by SMS feature";
+$messages['noreseturl'] = "Reset by mail tokens feature requires configuration of reset URL";
 $messages['ldaperror'] = "無法連接至 LDAP 伺服器";
 $messages['loginrequired'] = "請輸入帳號";
 $messages['oldpasswordrequired'] = "請輸入原密碼";
@@ -34,6 +36,7 @@ $messages['confirmpasswordrequired'] = "請確認您的新密碼";
 $messages['passwordchanged'] = "您的密碼已修改完成";
 $messages['sshkeychanged'] = "您的 SSH 金鑰已修改完成";
 $messages['nomatch'] = "密碼不符";
+$messages['insufficiententropy'] = "Insufficient entropy for new password";
 $messages['badcredentials'] = "帳號或密碼不正確";
 $messages['passworderror'] = "密碼被 LDAP 伺服器拒絶";
 $messages['sshkeyerror'] = "SSH 金鑰被 LDAP 伺服器拒絶";
@@ -108,8 +111,8 @@ $messages['notcomplex'] = "您的密碼沒有包含足夠的字元類型";
 $messages['policycomplex'] = "最少字元類型：";
 $messages['sms'] = "簡訊號碼";
 $messages['smsresetmessage'] = "您的密碼重新設定金鑰：";
-$messages['sendsmshelp'] = "輸入您的帳號讀取密碼重新設定簡訊。然後輸入簡訊中的金鑰。";
 $messages['smssent'] = "金鑰簡訊已發送";
+$messages['smssent_ifexists'] = "If account exists, a confirmation code has been send by SMS";
 $messages['smsnotsent'] = "簡訊發送錯誤";
 $messages['smsnonumber'] = "未發現手機號碼";
 $messages['userfullname'] = "帳號全名";
@@ -145,6 +148,7 @@ $messages['forbiddenwords'] = "Your passwords contains forbidden words or string
 $messages['policyforbiddenwords'] = "Your password must not contain:";
 $messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
 $messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
+$messages['policyentropy'] = "Password strength";
 $messages['ldap_cn'] = "common name";
 $messages['ldap_givenName'] = "given name";
 $messages['ldap_sn'] = "surname";
@@ -153,3 +157,24 @@ $messages["questionspopulatehint"] = "Enter only your login to retrieve the ques
 $messages['badquality'] = "Password quality is too low";
 $messages['tooyoung'] = "Password was changed too recently";
 $messages['inhistory'] = "Password is in history of old passwords";
+$messages['changecustompwdfieldhelp'] = "To change your password, you have to enter your credentials.";
+$messages['changehelpcustompwdfield'] = "change your password for ";
+$messages['newcustompassword'] = "new password for ";
+$messages['confirmcustompassword'] = "confirm new password";
+$messages['menucustompwdfield'] = "Password for ";
+$messages['unknowncustompwdfield'] = "The password field specified in the link cannot be found";
+$messages['sameascustompwd'] = "The new password is not unique across other password fields";
+$messages['attributesmoderror'] = "Your information have not been updated";
+$messages['attributeschanged'] = "Your information have been updated";
+$messages['setattributeshelp'] = "You can update the information used to reset your password. Enter your login and password and set your new details.";
+$messages['phone'] = "Telephone number";
+$messages['sendtokenhelpupdatemail'] = "You can udate your email address on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpupdatephone'] = "You can update your phone number on <a href=\"?action=setattributes\">this page</a>.";
+$messages['sendsmshelpnosms'] = "輸入您的帳號讀取密碼重新設定簡訊。然後輸入簡訊中的金鑰。";
+$messages['sendsmshelp'] = "Enter your login and your SMS number to get password reset token. Then type token in sent SMS.";
+$messages['smsrequired'] = "Your SMS phone is required.";
+$messages['smsnomatch'] = "The SMS number does not match the submitted login.";
+$messages['sameasaccountpassword'] = "Your new password is identical to your login password";
+$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
+$messages['missingformtoken'] = "Missing token";
+$messages['invalidformtoken'] = "Invalid token";
